pub struct AppRecord {
pub app: Value,
pub branches: BTreeMap<String, Value>,
pub domains: BTreeMap<String, Value>,
pub backend_environments: BTreeMap<String, Value>,
pub jobs: BTreeMap<String, BTreeMap<String, Value>>,
pub next_job_id: BTreeMap<String, u64>,
}Expand description
One Amplify app plus the child resources it owns.
Fields
app: ValueThe App wire object (camelCase members matching GetApp).
branches: BTreeMap<String, Value>Branches keyed by branchName; each value is a Branch wire object.
domains: BTreeMap<String, Value>Domain associations keyed by domainName; DomainAssociation objects.
backend_environments: BTreeMap<String, Value>Backend environments keyed by environmentName.
jobs: BTreeMap<String, BTreeMap<String, Value>>Jobs keyed by branchName then jobId; each value is a Job object
({ "summary": {...}, "steps": [...] }).
next_job_id: BTreeMap<String, u64>Next job id to allocate, per branch (Amplify job ids are numeric and monotonically increasing within a branch).